@@ -48,7 +48,7 @@ def _list_sum(values: list, prop: str): return sum(map(lambda v: _safe_cast(v.ge
 
 
 def _list_sum_terms(values: list, term_ids=[]):
-    return sum([_value_average(node) for node in values if node.get('term').get('@id') in term_ids])
+    return sum([_value_average(node) for node in values if node.get('term', {}).get('@id') in term_ids])
 
 
 def _filter_list(values: list, key: str, value): return list(filter(lambda v: _get_dict_key(v, key) == value, values))
