@@ -118,7 +118,7 @@ def validate_value_min_max(measurements: list):
             'message': f"should be below {maximum}"
         })
 
-    return _filter_list_errors(list(map(validate, enumerate(measurements))))
+    return _filter_list_errors(map(validate, enumerate(measurements)))
 
 
 def validate_term_unique(measurements: list):
@@ -139,4 +139,4 @@ def validate_term_unique(measurements: list):
             'message': 'must be unique'
         }
 
-    return _filter_list_errors(list(map(validate, enumerate(measurements))))
+    return _filter_list_errors(map(validate, enumerate(measurements)))
