@@ -104,7 +104,7 @@ def validate_list_term_percent(node: dict, list_key: str):
         value = values[1]
         units = value.get('term', {}).get('units', '')
         value = _value_average(value, None)
-        return units != '% (0-100)' or value is None or type(value) == str or \
+        return units != '%' or value is None or type(value) == str or \
             soft_validate(index, value) or hard_validate(index, value)
 
     return _filter_list_errors(list(map(validate, enumerate(node.get(list_key, [])))))
