@@ -7,7 +7,7 @@ from .shared import validate_region, validate_country, validate_coordinates, nee
 from .shared import validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy
 from .infrastructure import validate_lifespan
 from .measurement import validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique
-from .practice import validate_cropResidueManagement
+from .practice import validate_cropResidueManagement, validate_longFallowPeriod
 
 
 INLAND_TYPES = [
@@ -39,7 +39,7 @@ def validate_site_coordinates(site: dict):
 
 def validate_siteType(site: dict):
     site_type = site.get('siteType')
-    values = SITE_TYPES_VALID_VALUES[site_type] if site_type in SITE_TYPES_VALID_VALUES else []
+    values = SITE_TYPES_VALID_VALUES.get(site_type, [])
     values_str = ', '.join(map(lambda v: str(v), values))
 
     def validate():
@@ -110,5 +110,6 @@ def validate_site(site: dict, nodes=[]):
         validate_list_dates(site, 'practices'),
         validate_list_min_max(site, 'practices'),
         validate_list_term_percent(site, 'practices'),
-        validate_cropResidueManagement(site.get('practices'))
+        validate_cropResidueManagement(site.get('practices')),
+        validate_longFallowPeriod(site.get('practices'))
     ] if 'practices' in site else [])
